[![PyPI version](https://badge.fury.io/py/unrealai.svg)](https://badge.fury.io/py/unrealai)

[![Build Status](https://travis-ci.org/nishgaba-ai/unrealai.svg?branch=master)](https://travis-ci.org/nishgaba-ai/unrealai)

## Contributing [![contributions welcome](https://img.shields.io/badge/contributions-welcome-brightgreen.svg?style=flat)](https://github.com/nishgaba-ai/unrealai/issues)

# unrealai
Image/Machine Learning Tool Interface


# Installation
Run the following to install:

'''python
pip install unrealai
'''

## Usage
'''python
from helloworld import say_hello

# Generate "Hello, World!"
say_hello()

# Generate "Hello, Everybody!"
say_hello("Everybody")
'''
